@@ -10,12 +10,12 @@ sub getEmployeeData {
    my $pkg = shift;
    my $app = CAM::SOAPApp->new(soapdata => \@_);
    my %data = $app->getSOAPData();
-   unless ($data{ssn} && $data{ssn} eq "111-11-1111") {
-      $app->error("BadSSN", "Don't know that employee");
+   if (!$data{ssn} || $data{ssn} ne '111-11-1111') {
+      $app->error('BadSSN', 'Never heard of that employee');
    }
-   return $app->response(name => "John Smith",
-                         birthdate => "1969-01-01",
-                         phone => "212-555-1212");
+   return $app->response(name => 'John Smith',
+                         birthdate => '1969-01-01',
+                         phone => '212-555-1212');
 }
 
 sub fail {
